@@ -1,6 +1,6 @@
 import datetime
 import logging
-
+import twilio
 from twilio import TwilioException
 from twilio import TwilioRestException
 from urllib import urlencode
@@ -115,10 +115,10 @@ def make_request(method, url,
 
     See the requests documentation for explanation of all these parameters
 
-    Currently timeout, allow_redirects, proxies, files, and cookies
-    are all ignored
+    Currently proxies, files, and cookies are all ignored
     """
-    http = httplib2.Http()
+    http = httplib2.Http(timeout=timeout)
+    http.follow_redirects = allow_redirects
 
     if auth is not None:
         http.add_credentials(auth[0], auth[1])
@@ -132,7 +132,7 @@ def make_request(method, url,
             url = '%s&%s' % (url, enc_params)
         else:
             url = '%s?%s' % (url, enc_params)
-
+    
     resp, content = http.request(url, method, headers=headers, body=data)
 
     # Format httplib2 reqeusts as reqeusts objects
@@ -144,7 +144,7 @@ def make_twilio_request(method, uri, **kwargs):
     Make a request to Twilio. Throws an error
     """
     headers = kwargs.get("headers", {})
-    headers["User-Agent"] = "twilio-python/3.2.0"   # Add user aggent string
+    headers["User-Agent"] = "twilio-python/%s" % twilio.__version__
 
     if method == "POST" and "Content-Type" not in headers:
         headers["Content-Type"] = "application/x-www-form-urlencoded"
@@ -209,6 +209,7 @@ class Resource(object):
 class InstanceResource(Resource):
 
     subresources = []
+    id_key = "sid"
 
     def __init__(self, parent, sid):
         self.parent = parent
@@ -343,7 +344,7 @@ class ListResource(Resource):
             pass
 
     def load_instance(self, data):
-        instance = self.instance(self, data["sid"])
+        instance = self.instance(self, data[self.instance.id_key])
         instance.load(data)
         instance.load_subresources()
         return instance
@@ -451,7 +452,7 @@ class Recordings(ListResource):
     def list(self, call_sid=None, before=None, after=None, **kwargs):
         """
         Returns a page of :class:`Recording` resources as a list.
-        For paging informtion see :class:`ListResource`.
+        For paging information see :class:`ListResource`.
 
         :param date after: Only list recordings logged after this datetime
         :param date before: Only list recordings logger before this datetime
@@ -513,6 +514,50 @@ class Notifications(ListResource):
         return self.delete_instance(sid)
 
 
+class ConnectApp(InstanceResource):
+    """ An authorized connect app """
+    pass
+
+
+class ConnectApps(ListResource):
+    """ A list of Call resources """
+
+    name = "ConnectApps"
+    instance = ConnectApp
+    key = "connect_apps"
+
+    def list(self, **kwargs):
+        """
+        Returns a page of :class:`Call` resources as a list. For paging
+        informtion see :class:`ListResource`
+        """
+        return self.get_instances(**kwargs)
+
+
+class AuthorizedConnectApp(ConnectApp):
+    """ An authorized connect app """
+
+    id_key = "connect_app_sid"
+
+    def load(self, entries):
+        """ Translate certain parameters into others"""
+        result = {}
+
+        for k, v in entries.iteritems():
+            k = k.replace("connect_app_", "")
+            result[k] = v
+
+        super(AuthorizedConnectApp, self).load(result)
+
+
+class AuthorizedConnectApps(ConnectApps):
+    """ A list of Call resources """
+
+    name = "AuthorizedConnectApps"
+    instance = AuthorizedConnectApp
+    key = "authorized_connect_apps"
+
+
 class Call(InstanceResource):
     """ A call resource """
 
@@ -538,6 +583,13 @@ class Call(InstanceResource):
         a = self.parent.hangup(self.name)
         self.load(a.__dict__)
 
+    def cancel(self):
+        """ If the called is queued or rining, cancel the calls.
+        Will not affect in progress calls
+        """
+        a = self.parent.cancel(self.name)
+        self.load(a.__dict__)
+
     def route(self, **kwargs):
         """Route the specified :class:`Call` to another url.
 
@@ -571,10 +623,10 @@ class Calls(ListResource):
             "Status": status,
             "StartTime<": started_before,
             "StartTime>": started_after,
-            "StartTime": started,
+            "StartTime": parse_date(started),
             "EndTime<": ended_before,
             "EndTime>": ended_after,
-            "EndTime": ended,
+            "EndTime": parse_date(ended),
             })
         return self.get_instances(params=params, **kwargs)
 
@@ -609,6 +661,15 @@ class Calls(ListResource):
             })
         return self.update_instance(sid, params)
 
+    def cancel(self, sid):
+        """ If this call is queued or ringing, cancel the call
+        Will not affect in-progress calls.
+
+        :param sid: A Call Sid for a specific call
+        :returns: Updated :class:`Call` resource
+        """
+        return self.update(sid, status=Call.CANCELED)
+
     def hangup(self, sid):
         """ If this call is currenlty active, hang up the call.
         If this call is scheduled to be made, remove the call
@@ -617,7 +678,7 @@ class Calls(ListResource):
         :param sid: A Call Sid for a specific call
         :returns: Updated :class:`Call` resource
         """
-        return self.update(sid, status=Call.CANCELED)
+        return self.update(sid, status=Call.COMPLETED)
 
     def route(self, sid, url, method="POST"):
         """Route the specified :class:`Call` to another url.
@@ -667,7 +728,7 @@ class CallerIds(ListResource):
             "PhoneNumber": phone_number,
             "FrienldyName": friendly_name,
             })
-        return self.get_instances(params=params, **kwargs)
+        return self.get_instances(params=params, **kwargs) 
 
     def update(self, sid, friendly_name=None):
         """
@@ -939,6 +1000,7 @@ class SmsMessages(ListResource):
             })
         return self.create_instance(params)
 
+    @normalize_dates
     def list(self, to=None, from_=None, before=None, after=None, **kwargs):
         """
         Returns a page of :class:`SMSMessage` resources as a list. For
@@ -1104,6 +1166,7 @@ class Conferences(ListResource):
     name = "Conferences"
     instance = Conference
 
+    @normalize_dates
     def list(self, status=None, friendly_name=None, updated_before=None,
              updated_after=None, created_after=None, created_before=None,
              updated=None, created=None, **kwargs):
@@ -1122,12 +1185,12 @@ class Conferences(ListResource):
             "FriendlyName": friendly_name,
             "DateUpdated<": updated_before,
             "DateUpdated>": updated_after,
-            "DateUpdated": updated,
+            "DateUpdated=": parse_date(updated),
             "DateCreated<": created_before,
             "DateCreated>": created_after,
-            "DateCreated": created,
+            "DateCreated=": parse_date(created),
             })
-        return self.get_instance(params=params, **kwargs)
+        return self.get_instances(params=params, **kwargs)
 
 
 class Application(InstanceResource):
@@ -1168,7 +1231,7 @@ class Applications(ListResource):
                voice_fallback_method=None, status_callback=None,
                status_callback_method=None, voice_caller_id_lookup=None,
                sms_url=None, sms_method=None, sms_fallback_url=None,
-               sms_status_callback=None):
+               sms_fallback_method=None, sms_status_callback=None):
         """
         Update an :class:`Application` with any of these optional parameters.
 
@@ -1233,7 +1296,7 @@ class Applications(ListResource):
                voice_fallback_method=None, status_callback=None,
                status_callback_method=None, voice_caller_id_lookup=None,
                sms_url=None, sms_method=None, sms_fallback_url=None,
-               sms_status_callback=None):
+               sms_fallback_method=None, sms_status_callback=None):
         """
         Update an :class:`Application` with the given parameters.
 
@@ -1253,7 +1316,7 @@ class Applications(ListResource):
                 "SmsFallbackMethod": sms_fallback_method,
                 "SmsStatusCallback": sms_status_callback,
                 })
-        return self.update_instance(params)
+        return self.update_instance(sid, params)
 
     def delete(self, sid):
         """
@@ -1279,6 +1342,8 @@ class Account(InstanceResource):
         CallerIds,
         PhoneNumbers,
         Conferences,
+        ConnectApps,
+        AuthorizedConnectApps,
         ]
 
     def update(self, **kwargs):
